@@ -5,7 +5,7 @@ from humps import camelize, decamelize
 PRIVATE_TOKEN = '_'  # noqa: S105
 NODE_KEY_TOKEN = '_n'  # noqa: S105
 FORBIDDEN_KEYS = frozenset(('from', 'type'))
-NONSERIALIZABLE_TYPES = frozenset((int, float, bool))
+NONSERIALIZABLE_TYPES = frozenset((int, float, bool, dict))
 
 
 class Serializable:
@@ -113,9 +113,9 @@ class Serializable:
         """
         if isinstance(value, Serializable):
             return value.to_json()
-        if type(value) in NONSERIALIZABLE_TYPES:  # noqa:WPS516
-            return value
-        return str(value)
+        if hasattr(value, '__dict__'):  # noqa: WPS421
+            return str(value)
+        return value
 
     def __should_serialize_property(self, key: str, value) -> bool:
         return not key.startswith(PRIVATE_TOKEN) and value is not None
